@@ -373,9 +373,9 @@ sub set_build_features {
 
     # Mask features that are not available on certain architectures.
     if (none { $os eq $_ } qw(linux hurd) or
-        any { $cpu eq $_ } qw(alpha hppa ia64)) {
+        any { $cpu eq $_ } qw(alpha hppa ia64 m68k sh4 x32)) {
         # Disabled on non-(linux/hurd).
-        # Disabled on alpha, hppa, ia64.
+        # Disabled on alpha, hppa, ia64, m68k, sh4, x32.
         $use_feature{hardening}{pie} = 0;
     }
     if (any { $cpu eq $_ } qw(ia64 alpha hppa nios2) or $arch eq 'arm') {
@@ -659,7 +659,6 @@ sub add_build_flags {
         # be on derivatives.
         if (defined $flag) {
             $flags->append($_, $flag) foreach @compile_flags;
-            $flags->append('LDFLAGS', $flag);
         }
     }
 
